@@ -1,6 +1,12 @@
-"Main interface for qldb service type defs"
-from __future__ import annotations
+"""
+Main interface for qldb service type definitions.
 
+Usage::
+
+    from mypy_boto3.qldb.type_defs import CreateLedgerResponseTypeDef
+
+    data: CreateLedgerResponseTypeDef = {...}
+"""
 from datetime import datetime
 import sys
 from typing import Dict, IO, List, Union
@@ -15,6 +21,26 @@ else:
     from typing_extensions import TypedDict
 
 
+__all__ = (
+    "CreateLedgerResponseTypeDef",
+    "S3EncryptionConfigurationTypeDef",
+    "S3ExportConfigurationTypeDef",
+    "JournalS3ExportDescriptionTypeDef",
+    "DescribeJournalS3ExportResponseTypeDef",
+    "DescribeLedgerResponseTypeDef",
+    "ExportJournalToS3ResponseTypeDef",
+    "ValueHolderTypeDef",
+    "GetBlockResponseTypeDef",
+    "GetDigestResponseTypeDef",
+    "GetRevisionResponseTypeDef",
+    "ListJournalS3ExportsForLedgerResponseTypeDef",
+    "ListJournalS3ExportsResponseTypeDef",
+    "LedgerSummaryTypeDef",
+    "ListLedgersResponseTypeDef",
+    "ListTagsForResourceResponseTypeDef",
+    "UpdateLedgerResponseTypeDef",
+)
+
 CreateLedgerResponseTypeDef = TypedDict(
     "CreateLedgerResponseTypeDef",
     {
